about summary refs log tree commit diff
path: root/boot/scripts/embed.sh
diff options
context:
space:
mode:
authorMel <mel@rnrd.eu>2026-01-27 04:15:32 +0100
committerMel <mel@rnrd.eu>2026-01-27 04:15:32 +0100
commit129e5669015a7ffd78d0f665f46cc434bcf126d2 (patch)
tree97c203070590cf27bba2209c1998bcc546260753 /boot/scripts/embed.sh
parent38bc2d06fff322a99ba6ba46df69bbd2b40c6173 (diff)
downloadcatskill-129e5669015a7ffd78d0f665f46cc434bcf126d2.tar.zst
catskill-129e5669015a7ffd78d0f665f46cc434bcf126d2.zip
TinyCC (libtcc) backend for catboot HEAD main
Signed-off-by: Mel <mel@rnrd.eu>
Diffstat (limited to 'boot/scripts/embed.sh')
-rwxr-xr-xboot/scripts/embed.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/boot/scripts/embed.sh b/boot/scripts/embed.sh
index baf2e38..98a0c9d 100755
--- a/boot/scripts/embed.sh
+++ b/boot/scripts/embed.sh
@@ -2,7 +2,7 @@
 
 # embed.sh
 # a simple script to handle embedding binary file contents into invocations
 # of the CATSKILL_EMBED macro within catboot compiler source files.
 # invoked with `./embed.sh source-1.c source-2.c header.h`
 # outputs a file structure within the ./build/ directory matching the source
 # directory, with the correct replacements done.
@@ -23,9 +23,9 @@ process_file() {
 
     cp "$source_file" "$output_file"
 
-    local embed_regex='CATSKILL_EMBED\("([^)]+)"\)' # const byte data[] = CATSKILL_EMBED("./file");
-    local comment_regex='^\s*//' # // the macro CATSKILL_EMBED does...
-    local define_regex='^\s*#define' # #define CATSKILL_EMBED {0}
+    local embed_regex='CATBOOT_EMBED\("([^)]+)"\)' # const byte data[] = CATBOOT_EMBED("./file");
+    local comment_regex='^\s*//' # // the macro CATBOOT_EMBED does...
+    local define_regex='^\s*#define' # #define CATBOOT_EMBED {0}
 
     while IFS= read -r line; do
         # skip lines which are just comments mentioning the macro and
@@ -2,7 +2,7 @@
 # embed.sh
 # a simple script to handle embedding binary file contents into invocations
-# of the CATSKILL_EMBED macro within catboot compiler source files.
+# of the CATBOOT_EMBED macro within catboot compiler source files.
 # invoked with `./embed.sh source-1.c source-2.c header.h`
 # outputs a file structure within the ./build/ directory matching the source